The Basketball Diaries - Moviebox Official
Description: A teenager finds his dreams of becoming a basketball star threatened after he free falls into the harrowing world of drug addiction. all in Moviebox Official
Keywords: basketball sport,addiction,gay,masturbation reference,talking about masturbation,tank top,sunbathing,male wears underwear,taking off underwear,bare butt

Find any content infringes on your rights, please contact us.
Report
Resources
Source: ailok.pe By Dame gnahore
The Basketball Diaries

## The Basketball Diaries

1995-04-21 / 1 h 42 m
7.3
A teenager finds his dreams of becoming a basketball star threatened after he free falls into the harrowing world of drug addiction.
Download This Video
Share
United States / Biography / Crime / Drama
Subtitles: English,Filipino,Français,Indonesian,Português,اَلْعَرَبِيَّةُ,اُردُو,বাংলা,中文
Top Cast(18)
Leonardo DiCaprio
Jim Carroll
Lorraine Bracco
Jim's Mother
Marilyn Sokol
Chanting Woman
James Madio
Pedro
Patrick McGaw
Neutron
Mark Wahlberg
Mickey
Roy Cooper
Father McNulty
Vincent Pastore
Construction Worker
Bruno Kirby
Swifty
Jimmy Papiris
Iggy
Nick Gaetani
Referee #1
Alexander Chaplin
Bobo
Ben Jorgensen
Tommy
Josh Mostel
Counterman
Juliette Lewis
Diane Moody
Michael Imperioli
Bobby
Akiko Ashley
Stripper
Ernie Hudson
Reggie
For You
See more
Hot movies
Hot TV/Series